@@ -491,6 +491,9 @@ class Target(object):
 
     def _hard_reboot(self, connection):
         logging.info("Perform hard reset on the system")
+        if self.config.pre_power_cmd:
+            self.context.run_command(self.config.pre_power_cmd,
+                                     failok=True)
         if self.config.hard_reset_command != "":
             self.context.run_command(self.config.hard_reset_command)
         else:
@@ -542,6 +545,10 @@ class Target(object):
 
     def _monitor_boot(self, connection, ps1, ps1_pattern, is_master=False):
 
+        if self.config.pre_os_cmd:
+            self.context.run_command(self.config.pre_os_cmd,
+                                     failok=True)
+
         good = 'pass'
         bad = 'fail'
         if not is_master:
@@ -855,6 +862,13 @@ class Target(object):
             if mounted:
                 runner.run('umount /mnt')
 
+    def _politely_close_console(self, connection):
+        if "telnet" in self.config.connection_command:
+            logging.debug("Telnet connection: Closing connection nicely")
+            connection.sendcontrol("]")
+            connection.expect("telnet> ", timeout=2)
+            connection.send("quit")
+
     def _start_busybox_http_server(self, runner, ip):
         runner.run('busybox httpd -f -p %d &' % self.config.busybox_http_port)
         runner.run('echo $! > /tmp/httpd.pid')
