@@ -18,6 +18,7 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
+import re
 import logging
 import os
 import sys
@@ -26,6 +27,7 @@ import time
 import types
 import signal
 import datetime
+import traceback
 import subprocess
 from collections import OrderedDict
 from contextlib import contextmanager
@@ -119,6 +121,26 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
         if not action:
             raise RuntimeError("Unable to add empty action to pipeline")
 
+    def _override_action_timeout(self, action, override):
+        if not isinstance(override, dict):
+            return
+        action.timeout = Timeout(
+            action.name,
+            Timeout.parse(
+                override[action.name]
+            )
+        )
+
+    def _override_connection_timeout(self, action, override):
+        if not isinstance(override, dict):
+            return
+        action.connection_timeout = Timeout(
+            action.name,
+            Timeout.parse(
+                override[action.name]
+            )
+        )
+
     def add_action(self, action, parameters=None):
         self._check_action(action)
         self.actions.append(action)
@@ -149,26 +171,36 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
             parameters = self.parameters
         # if the action has an internal pipeline, initialise that here.
         action.populate(parameters)
+        if 'default_connection_timeout' in parameters:
+            # some action handlers do not need to pass all parameters to their children.
+            action.connection_timeout.duration = parameters['default_connection_timeout']
         # Set the timeout
         # FIXME: only the last test is really useful. The first ones are only
         # needed to run the tests that do not use a device and job.
-        if self.job is not None and \
-           self.job.device is not None and \
-           action.name in self.job.device.get('timeouts', {}):
-            action.timeout = Timeout(
-                action.name,
-                Timeout.parse(
-                    self.job.device['timeouts'][action.name]
-                )
-            )
+        if self.job is not None and self.job.device is not None:
+            # set device level overrides
+            overrides = self.job.device.get('timeouts', {})
+            if 'actions' in overrides and action.name in overrides['actions']:
+                self._override_action_timeout(action, overrides['actions'])
+            elif action.name in overrides:
+                self._override_action_timeout(action, overrides)
+            if 'connections' in overrides and action.name in overrides['connections']:
+                self._override_connection_timeout(action, overrides['connections'])
         # Set the parameters after populate so the sub-actions are also
         # getting the parameters.
         # Also set the parameters after the creation of the default timeout
         # so timeouts specified in the job override the defaults.
         # job overrides device timeouts:
-        # FIXME: this shouldn't be needed once the device configuration is generated using the job definition
-        if self.job and 'timeouts' in self.job.parameters and action.name in self.job.parameters['timeouts']:
-            parameters['timeout'] = self.job.parameters['timeouts'][action.name]
+        if self.job and 'timeouts' in self.job.parameters:
+            overrides = self.job.parameters['timeouts']
+            if 'actions' in overrides and action.name in overrides:
+                # set job level overrides
+                self._override_action_timeout(action, overrides['actions'])
+            elif action.name in overrides:
+                self._override_action_timeout(action, overrides)
+                parameters['timeout'] = overrides[action.name]
+            if 'connections' in overrides and action.name in overrides:
+                self._override_connection_timeout(action, overrides['connections'])
 
         action.parameters = parameters
 
@@ -300,27 +332,20 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
                     signal.signal(signal.SIGINT, cancelling_handler)
                     signal.signal(signal.SIGTERM, cancelling_handler)
                 start = time.time()
-                new_connection = None
                 try:
-                    # FIXME: not sure to understand why we have two cases here?
-                    if not connection:
-                        with action.timeout.action_timeout():
-                            new_connection = action.run(connection, args)
-                    else:
+                    with action.timeout.action_timeout():
                         new_connection = action.run(connection, args)
                 # overly broad exceptions will cause issues with RetryActions
                 # always ensure the unit tests continue to pass with changes here.
-                except (ValueError, KeyError, TypeError, RuntimeError, AttributeError) as exc:
-                    exc_type, exc_value, exc_traceback = sys.exc_info()
-                    traceback_details = {
-                        'filename': exc_traceback.tb_frame.f_code.co_filename,
-                        'lineno': exc_traceback.tb_lineno,
-                        'name': exc_traceback.tb_frame.f_code.co_name,
-                        'type': exc_type.__name__,
-                        'message': exc_value.message,
-                    }
-                    action.logger.exception(traceback_details)
-                    raise RuntimeError(exc)
+                except (ValueError, KeyError, NameError, SyntaxError, OSError,
+                        TypeError, RuntimeError, AttributeError):
+                    msg = re.sub('\s+', ' ', ''.join(traceback.format_exc().split('\n')))
+                    action.logger.exception(msg)
+                    action.errors = msg
+                    action.cleanup()
+                    self.cleanup_actions(connection, None)
+                    # report action errors so that the last part of the message is the most relevant.
+                    raise RuntimeError(action.errors)
                 except KeyboardInterrupt:
                     raise KeyboardInterrupt
                 action.elapsed_time = time.time() - start
@@ -393,6 +418,7 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
         self.diagnostics = []
         self.protocols = []  # list of protocol objects supported by this action, full list in job.protocols
         self.section = None
+        self.connection_timeout = Timeout(self.name)
 
     # public actions (i.e. those who can be referenced from a job file) must
     # declare a 'class-type' name so they can be looked up.
@@ -514,6 +540,8 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
         # Overide the duration if needed
         if 'timeout' in self.parameters:
             self.timeout.duration = Timeout.parse(self.parameters['timeout'])
+        if 'connection_timeout' in self.parameters:
+            self.connection_timeout.duration = Timeout.parse(self.parameters['connection_timeout'])
 
         # only unit tests should have actions without a pointer to the job.
         if 'failure_retry' in self.parameters and 'repeat' in self.parameters:
@@ -652,7 +680,7 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
         if self.internal_pipeline:
             return self.internal_pipeline.run_actions(connection, args)
         if connection:
-            connection.timeout = self.timeout
+            connection.timeout = self.connection_timeout
         return connection
 
     def cleanup(self):
