@@ -27,3 +27,5 @@ from lava_dispatcher.pipeline.actions.boot.qemu import BootQEMU, VirtualMachine
 from lava_dispatcher.pipeline.actions.boot.u_boot import UBoot
 from lava_dispatcher.pipeline.actions.boot.kexec import BootKExec
 from lava_dispatcher.pipeline.actions.boot.ssh import SshLogin, Schroot
+from lava_dispatcher.pipeline.actions.boot.fastboot import BootFastboot
+from lava_dispatcher.pipeline.actions.boot.uefi_menu import UefiMenu
