@@ -24,7 +24,6 @@
 from lava_dispatcher.pipeline.action import (
     Action,
     Pipeline,
-    JobError,
     Timeout,
     InfrastructureError,
 )
@@ -38,7 +37,6 @@ from lava_dispatcher.pipeline.utils.constants import (
     UBOOT_AUTOBOOT_PROMPT,
     UBOOT_DEFAULT_CMD_TIMEOUT,
     BOOT_MESSAGE,
-    SHUTDOWN_MESSAGE,
 )
 from lava_dispatcher.pipeline.utils.strings import substitute
 from lava_dispatcher.pipeline.utils.network import dispatcher_ip
@@ -68,6 +66,8 @@ class UBoot(Boot):
     hand this pexpect wrapper to subsequent actions as a shell connection.
     """
 
+    compatibility = 1
+
     def __init__(self, parent, parameters):
         super(UBoot, self).__init__(parent)
         self.action = UBootAction()
@@ -156,8 +156,9 @@ class UBootRetry(BootAction):
     def run(self, connection, args=None):
         connection = super(UBootRetry, self).run(connection, args)
         self.logger.debug("Setting default test shell prompt")
-        connection.prompt_str = self.job.device['test_image_prompts']
-        connection.timeout = self.timeout
+        if not connection.prompt_str:
+            connection.prompt_str = self.parameters['prompts']
+        connection.timeout = self.connection_timeout
         self.wait(connection)
         self.data['boot-result'] = 'failed' if self.errors else 'success'
         return connection
@@ -327,8 +328,14 @@ class UBootCommandOverlay(Action):
         substitutions['{KERNEL}'] = self.get_common_data('file', 'kernel')
         substitutions['{DTB}'] = self.get_common_data('file', 'dtb')
 
+        nfs_url = self.get_common_data('nfs_url', 'nfsroot')
         if 'download_action' in self.data and 'nfsrootfs' in self.data['download_action']:
             substitutions['{NFSROOTFS}'] = self.get_common_data('file', 'nfsroot')
+            substitutions['{NFS_SERVER_IP}'] = ip_addr
+        elif nfs_url:
+
+            substitutions['{NFSROOTFS}'] = nfs_url
+            substitutions['{NFS_SERVER_IP}'] = self.get_common_data('nfs_url', 'serverip')
 
         substitutions['{ROOT}'] = self.get_common_data('uuid', 'root')  # UUID label, not a file
         substitutions['{ROOT_PART}'] = self.get_common_data('uuid', 'boot_part')
