@@ -1,4 +1,4 @@
-# Copyright (C) 2014 Linaro Limited
+# Copyright (C) 2014,2015 Linaro Limited
 #
 # Author: Neil Williams <neil.williams@linaro.org>
 #
@@ -22,13 +22,13 @@
 # imported by the parser to populate the list of subclasses.
 
 import os
-from lava_dispatcher.pipeline.action import Pipeline, InfrastructureError
+from lava_dispatcher.pipeline.action import Pipeline
 from lava_dispatcher.pipeline.logical import Deployment
 from lava_dispatcher.pipeline.actions.deploy import DeployAction
 from lava_dispatcher.pipeline.actions.deploy.download import DownloaderAction
 from lava_dispatcher.pipeline.actions.deploy.apply_overlay import PrepareOverlayTftp
 from lava_dispatcher.pipeline.actions.deploy.environment import DeployDeviceEnvironment
-from lava_dispatcher.pipeline.utils.shell import which
+from lava_dispatcher.pipeline.utils.shell import infrastructure_error
 from lava_dispatcher.pipeline.utils.filesystem import mkdtemp, tftpd_dir
 from lava_dispatcher.pipeline.utils.constants import DISPATCHER_DOWNLOAD_DIR
 
@@ -61,6 +61,9 @@ class Tftp(Deployment):
     Limited to what the bootloader can deploy which means ramdisk or nfsrootfs.
     rootfs deployments would format the device and create a single partition for the rootfs.
     """
+
+    compatibility = 1
+
     def __init__(self, parent, parameters):
         super(Tftp, self).__init__(parent)
         self.action = TftpAction()
@@ -83,7 +86,7 @@ class TftpAction(DeployAction):  # pylint:disable=too-many-instance-attributes
         super(TftpAction, self).__init__()
         self.name = "tftp-deploy"
         self.description = "download files and deploy using tftp"
-        self.summary = "tftp deploment"
+        self.summary = "tftp deployment"
         self.tftp_dir = tftpd_dir()
         self.suffix = None
         try:
@@ -103,15 +106,14 @@ class TftpAction(DeployAction):  # pylint:disable=too-many-instance-attributes
             self.errors = "%s needs a kernel to deploy" % self.name
         if not self.valid:
             return
+        if 'nfsrootfs' in self.parameters and 'nfs_url' in self.parameters:
+            self.errors = "Only one of nfsrootfs or nfs_url can be specified"
         lava_test_results_dir = self.parameters['deployment_data']['lava_test_results_dir']
         self.data['lava_test_results_dir'] = lava_test_results_dir % self.job.job_id
         if self.suffix:
             self.data[self.name].setdefault('suffix', self.suffix)
         self.data[self.name].setdefault('suffix', os.path.basename(self.tftp_dir))
-        try:
-            which("in.tftpd")
-        except InfrastructureError as exc:
-            self.errors = str(exc)
+        self.errors = infrastructure_error('in.tftpd')
 
     def populate(self, parameters):
         self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
