@@ -125,6 +125,10 @@ class Connection(object):
         self.results = {}
         self.match = None
         self.connected = True
+        self.check_char = '#'
+
+    def corruption_check(self):
+        self.sendline(self.check_char)
 
     def sendline(self, line):
         if self.connected:
@@ -172,8 +176,8 @@ class CommandRunner(object):
         # self.logger.debug("Changing prompt to %s" % string)
         self._prompt_str = string
 
-    def wait_for_prompt(self, timeout=-1):
-        wait_for_prompt(self._connection, self._prompt_str, timeout)
+    def wait_for_prompt(self, timeout=-1, check_char='#'):
+        wait_for_prompt(self._connection, self._prompt_str, timeout, check_char)
 
     def get_connection(self):
         return self._connection
@@ -234,8 +238,14 @@ class Protocol(object):  # pylint: disable=abstract-class-not-used
     or adding a main function in the protocol python file and including a demo server script which
     can be run on the command line - using a different port to the default. However, this is likely
     to be of limited use because testing the actual API calls will need a functional test.
+
+    If a Protocol requires another Protocol to be available in order to run, the depending
+    Protocol *must* specify a higher level. All Protocol objects of a lower level are setup and
+    run before Protocol objects of a higher level. Protocols with the same level can be setup or run
+    in an arbitrary order (as the original source data is a dictionary).
     """
     name = 'protocol'
+    level = 0
 
     def __init__(self, parameters):
         # FIXME: allow the bare logger to use the zmq socket
@@ -252,7 +262,7 @@ class Protocol(object):  # pylint: disable=abstract-class-not-used
         Jobs may have zero or more protocols selected.
         """
         candidates = cls.__subclasses__()  # pylint: disable=no-member
-        return [c for c in candidates if c.accepts(parameters)]
+        return [(c, c.level) for c in candidates if c.accepts(parameters)]
 
     @property
     def errors(self):
