@@ -71,8 +71,21 @@ SHUTDOWN_MESSAGE = 'The system is going down for reboot NOW'
 # Kernel starting message
 BOOT_MESSAGE = 'Booting Linux'
 
+# Default shell prompt for AutoLogin
+DEFAULT_SHELL_PROMPT = 'lava-test: # '
+
+# Distinctive prompt characters which can
+# help distinguish status messages from shell prompts.
+DISTINCTIVE_PROMPT_CHARACTERS = ":"
+
 # LAVA Coordinator setup and finalize timeout
 LAVA_MULTINODE_SYSTEM_TIMEOUT = 90
 
 # Default Action timeout
 ACTION_TIMEOUT = 30
+
+# Android tmp directory
+ANDROID_TMP_DIR = '/data/local/tmp'
+
+# Default timeout for fastboot reboot
+FASTBOOT_REBOOT_TIMEOUT = 10
